==> haskell-tabular-0.2.2.7-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-tabular.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tabular
version: 0.2.2.7
id: tabular-0.2.2.7-8UHVxBN1c9nJmHiguc2VpX
key: tabular-0.2.2.7-8UHVxBN1c9nJmHiguc2VpX
license: BSD3
maintainer: Eric Kow <eric.kow@gmail.com>
homepage: http://hub.darcs.net/kowey/tabular
synopsis: Two-dimensional data tables with rendering functions
description:
    Tabular provides a Haskell representation of two-dimensional
    data tables, the kind that you might find in a spreadsheet or
    or a research report.  It also comes with some default
    rendering functions for turning those tables into ASCII art,
    simple text with an arbitrary delimiter, CSV, HTML or LaTeX.
    .
    Below is an example of the kind of output this library produces.
    The tabular package can group rows and columns, each group
    having one of three separators (no line, single line, double line)
    between its members.
    .
    >     || memtest 1 | memtest 2 ||  time test  | time test 2
    > ====++===========+===========++=============+============
    > A 1 ||       hog |  terrible ||        slow |      slower
    > A 2 ||       pig |   not bad ||        fast |     slowest
    > ----++-----------+-----------++-------------+------------
    > B 1 ||      good |     awful || intolerable |    bearable
    > B 2 ||    better | no chance ||    crawling |     amazing
    > B 3 ||       meh |   well... ||  worst ever |          ok
category: Text
author: Eric Kow
exposed: True
indefinite: False
exposed-modules:
    Text.Tabular Text.Tabular.AsciiArt Text.Tabular.Csv
    Text.Tabular.Html Text.Tabular.Latex Text.Tabular.SimpleText
abi: c460a8945c9b02cdd925f820aa5b31d0
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/tabular-0.2.2.7
library-dirs: /usr/lib/ghc-8.2.2/site-local/tabular-0.2.2.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/tabular-0.2.2.7
hs-libraries: HStabular-0.2.2.7-8UHVxBN1c9nJmHiguc2VpX
depends:
    base-4.10.1.0 mtl-2.2.2-8XubxMJDT8QLsstvlNotkc
    csv-0.1.2-c2fjBQBo4S4ggrGOOVcp4 html-1.0.1.2-HJx3nTTgwhH7I2VQDflUHM
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             csv-0.1.2-c2fjBQBo4S4ggrGOOVcp4=4427d68d19560e7a16e9848c471ef872
             html-1.0.1.2-HJx3nTTgwhH7I2VQDflUHM=aa7e7bb2d474986fc227927ea5a6d356
haddock-interfaces: /usr/share/doc/haskell-tabular/html/tabular.haddock
haddock-html: /usr/share/doc/haskell-tabular/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tabular-0.2.2.7-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-tabular.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tabular
version: 0.2.2.7
id: tabular-0.2.2.7-HF2IJKR6TJrGdD2ud3QwlY
key: tabular-0.2.2.7-HF2IJKR6TJrGdD2ud3QwlY
license: BSD-3-Clause
maintainer: Eric Kow <eric.kow@gmail.com>
author: Eric Kow
homepage: http://hub.darcs.net/kowey/tabular
synopsis: Two-dimensional data tables with rendering functions
description:
    Tabular provides a Haskell representation of two-dimensional
    data tables, the kind that you might find in a spreadsheet or
    or a research report.  It also comes with some default
    rendering functions for turning those tables into ASCII art,
    simple text with an arbitrary delimiter, CSV, HTML or LaTeX.
    .
    Below is an example of the kind of output this library produces.
    The tabular package can group rows and columns, each group
    having one of three separators (no line, single line, double line)
    between its members.
    .
    >     || memtest 1 | memtest 2 ||  time test  | time test 2
    > ====++===========+===========++=============+============
    > A 1 ||       hog |  terrible ||        slow |      slower
    > A 2 ||       pig |   not bad ||        fast |     slowest
    > ----++-----------+-----------++-------------+------------
    > B 1 ||      good |     awful || intolerable |    bearable
    > B 2 ||    better | no chance ||    crawling |     amazing
    > B 3 ||       meh |   well... ||  worst ever |          ok
category: Text
abi: 406988501480082666ba7a2896144d5e
exposed: True
exposed-modules:
    Text.Tabular Text.Tabular.AsciiArt Text.Tabular.Csv
    Text.Tabular.Html Text.Tabular.Latex Text.Tabular.SimpleText
import-dirs: /usr/lib/ghc-8.4.3/site-local/tabular-0.2.2.7
library-dirs: /usr/lib/ghc-8.4.3/site-local/tabular-0.2.2.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/tabular-0.2.2.7
hs-libraries: HStabular-0.2.2.7-HF2IJKR6TJrGdD2ud3QwlY
depends:
    base-4.11.1.0 mtl-2.2.2 csv-0.1.2-EpTL7zD0nY4Lq2oA3vrN2m
    html-1.0.1.2-G4td77RosvCvhPgoBbjtm
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             csv-0.1.2-EpTL7zD0nY4Lq2oA3vrN2m=96eb36dad3db736296feabfd6b1391a1
             html-1.0.1.2-G4td77RosvCvhPgoBbjtm=60e8b343e2f069781d8c25bbef37fed4
haddock-interfaces: /usr/share/doc/haskell-tabular/html/tabular.haddock
haddock-html: /usr/share/doc/haskell-tabular/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
